@@ -1859,5 +1859,5 @@ def _match_error_to_data_set(x, ex):
     
 if __name__ == '__main__':  
     import spinmob
-    runfile(spinmob.__path__[0] + '/_tests/test__functions.py')
+    runfile(spinmob.__path__[0] + '/tests/test__functions.py')
      
\ No newline at end of file
